@@ -149,7 +149,6 @@ pub struct Allocation {
     heap: *mut d3d12::ID3D12Heap,
 
     name: Option<Box<str>>,
-    backtrace: Option<Box<str>>,
 }
 
 unsafe impl Send for Allocation {}
@@ -197,11 +196,11 @@ impl Default for Allocation {
             memory_type_index: !0,
             heap: std::ptr::null_mut(),
             name: None,
-            backtrace: None,
         }
     }
 }
 
+#[derive(Debug)]
 struct MemoryBlock {
     heap: std::ptr::NonNull<d3d12::ID3D12Heap>,
     sub_allocator: Box<dyn allocator::SubAllocator>,
@@ -275,6 +274,36 @@ struct MemoryType {
     active_general_blocks: usize,
 }
 
+struct HeapPropertiesDebug(d3d12::D3D12_HEAP_PROPERTIES);
+
+impl std::fmt::Debug for HeapPropertiesDebug {
+    fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
+        f.debug_struct("D3D12_HEAP_PROPERTIES")
+            .field("Type", &self.0.Type)
+            .field("CPUPageProperty", &self.0.CPUPageProperty)
+            .field("MemoryPoolPreference", &self.0.MemoryPoolPreference)
+            .field("CreationNodeMask", &self.0.CreationNodeMask)
+            .field("VisibleNodeMask", &self.0.VisibleNodeMask)
+            .finish()
+    }
+}
+
+impl std::fmt::Debug for MemoryType {
+    fn fmt(&self, f: &mut std::fmt::Formatter) -> std::fmt::Result {
+        f.debug_struct("MemoryType")
+            .field("memory_blocks", &self.memory_blocks)
+            .field("memory_location", &self.memory_location)
+            .field("heap_category", &self.heap_category)
+            .field(
+                "heap_properties",
+                &HeapPropertiesDebug(self.heap_properties),
+            )
+            .field("memory_type_index", &self.memory_type_index)
+            .field("active_general_blocks", &self.active_general_blocks)
+            .finish()
+    }
+}
+
 const DEFAULT_DEVICE_MEMBLOCK_SIZE: u64 = 256 * 1024 * 1024;
 const DEFAULT_HOST_MEMBLOCK_SIZE: u64 = 64 * 1024 * 1024;
 impl MemoryType {
@@ -338,7 +367,6 @@ impl MemoryType {
                 memory_type_index: self.memory_type_index as usize,
                 heap: mem_block.heap.as_ptr(),
                 name: Some(desc.name.into()),
-                backtrace: backtrace.map(|s| s.into()),
             });
         }
 
@@ -364,7 +392,6 @@ impl MemoryType {
                             memory_type_index: self.memory_type_index as usize,
                             heap: mem_block.heap.as_ptr(),
                             name: Some(desc.name.into()),
-                            backtrace: backtrace.map(|s| s.into()),
                         });
                     }
                     Err(AllocationError::OutOfMemory) => {} // Block is full, continue search.
@@ -422,7 +449,6 @@ impl MemoryType {
             memory_type_index: self.memory_type_index as usize,
             heap: mem_block.heap.as_ptr(),
             name: Some(desc.name.into()),
-            backtrace: backtrace.map(|s| s.into()),
         })
     }
 
@@ -459,6 +485,7 @@ impl MemoryType {
     }
 }
 
+#[derive(Debug)]
 pub struct Allocator {
     device: std::ptr::NonNull<d3d12::ID3D12Device>,
     debug_settings: AllocatorDebugSettings,
